function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { createContext, useState, useRef, useCallback, useContext } from "react";
const SocketScopeContext = createContext();
export const useAcquireSocket = () => {
  const {
    acquire
  } = useContext(SocketScopeContext) || {};
  return acquire;
};
export const useReleaseSocket = () => {
  const {
    release
  } = useContext(SocketScopeContext) || {};
  return release;
};
export const Provider = ({
  children
}) => {
  const sockets = useRef({});
  const [, setCounts] = useState({});
  const acquire = useCallback((url, keepAlive) => {
    let socket = sockets.current[url];

    if (!socket || socket && keepAlive && socket.readyState != WebSocket.CONNECTING && socket.readyState != WebSocket.OPEN) {
      socket = new WebSocket(url);
      sockets.current[url] = socket;
    }

    setCounts(cnts => _objectSpread({}, cnts, {
      [url]: (cnts[url] || 0) + 1
    }));
    return socket;
  }, []);
  const release = useCallback(url => {
    setCounts(counts => {
      const count = counts[url];
      if (!count) return counts;
      const newCount = count - 1;

      if (newCount == 0) {
        sockets.current[url].close();
        delete sockets.current[url];
        return _objectSpread({}, counts, {
          [url]: null
        });
      }

      return _objectSpread({}, counts, {
        [url]: newCount
      });
    });
  }, []);
  return React.createElement(SocketScopeContext.Provider, {
    value: {
      acquire,
      release
    }
  }, children);
};