"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = require("react");

const useSocketKeepAlive = ({
  socket,
  keepAlive,
  keepAliveMaxDelay,
  keepAliveAttempts: attempts,
  setKeepAliveAttempts: setAttempts
}) => {
  const timer = (0, _react.useRef)(null);
  const handler = (0, _react.useCallback)(() => {
    // https://favsub.com/bookmarks/edit/17993-john-ryding-blog-how-to-reconnect-web-sockets-in-a-realtime-web-app-without-flooding-the-server
    var time = generateInterval(attempts, keepAliveMaxDelay);
    timer.current = setTimeout(() => {
      setAttempts(c => c + 1);
    }, time);
  }, [attempts, setAttempts, keepAliveMaxDelay]);
  (0, _react.useEffect)(() => {
    if (socket && keepAlive) {
      socket.addEventListener("error", handler);
      socket.addEventListener("close", handler);
    }

    return () => {
      if (socket && keepAlive) {
        socket.removeEventListener("error", handler);
        socket.removeEventListener("close", handler);
      }

      if (timer.current) {
        clearTimeout(timer.current);
      }
    };
  }, [handler, keepAlive, socket]);
};

function generateInterval(k, keepAliveMaxDelay) {
  var maxInterval = (Math.pow(2, k) - 1) * 1000;

  if (maxInterval > keepAliveMaxDelay) {
    maxInterval = keepAliveMaxDelay; // If the generated interval is more than the max delay, truncate it down to the max delay.
  } // generate the interval to a random number between 0 and the maxInterval determined from above


  return Math.random() * maxInterval;
}

var _default = useSocketKeepAlive;
exports.default = _default;