"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Provider = exports.useReleaseSocket = exports.useAcquireSocket = void 0;

var _react = _interopRequireWildcard(require("react"));

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const SocketScopeContext = (0, _react.createContext)();

const useAcquireSocket = () => {
  const {
    acquire
  } = (0, _react.useContext)(SocketScopeContext) || {};
  return acquire;
};

exports.useAcquireSocket = useAcquireSocket;

const useReleaseSocket = () => {
  const {
    release
  } = (0, _react.useContext)(SocketScopeContext) || {};
  return release;
};

exports.useReleaseSocket = useReleaseSocket;

const Provider = ({
  children
}) => {
  const sockets = (0, _react.useRef)({});
  const [, setCounts] = (0, _react.useState)({});
  const acquire = (0, _react.useCallback)((url, keepAlive) => {
    let socket = sockets.current[url];

    if (!socket || socket && keepAlive && socket.readyState != WebSocket.CONNECTING && socket.readyState != WebSocket.OPEN) {
      socket = new WebSocket(url);
      sockets.current[url] = socket;
    }

    setCounts(cnts => _objectSpread({}, cnts, {
      [url]: (cnts[url] || 0) + 1
    }));
    return socket;
  }, []);
  const release = (0, _react.useCallback)(url => {
    setCounts(counts => {
      const count = counts[url];
      if (!count) return counts;
      const newCount = count - 1;

      if (newCount == 0) {
        sockets.current[url].close();
        delete sockets.current[url];
        return _objectSpread({}, counts, {
          [url]: null
        });
      }

      return _objectSpread({}, counts, {
        [url]: newCount
      });
    });
  }, []);
  return _react.default.createElement(SocketScopeContext.Provider, {
    value: {
      acquire,
      release
    }
  }, children);
};

exports.Provider = Provider;